device = 18F25K40

// SF assumes the interrupt priority bit IPEN is RCON.bits(7)
// for the K40 (and K42), there is no RCON register and
// IPEN has been moved to INTCON.bits(5)
dim IPEN as INTCON.bits(5)

// select single priority (false) or dual priority test (true)
#option USE_INTR_PRIORITY = false

#if (USE_INTR_PRIORITY = false)
// single intr
public interrupt ISR()
    if (PIR0.1 = 0) then
        PIR0.1 = 0
    endif
end interrupt

// this kludge defines an RCON register symbol so at least things will compile
// since SF will set/clear RCON.bits(7) automatically at the start of MAIN when 
// using interrupts we locate RCON at the WREG address so it doesn't cause any harm
// you'll have to manage INTCON.IPEN manually
public system RCON as byte absolute $0FE8
asm
RCON EQU 0x0FE8
end asm

IPEN = 1        // this replicates SF startup code
enable(ISR)

#else
// dual intr priority
public const
    ipLow = 1,
    ipHigh = 2

// high priority interrupt service routine
public interrupt HIGHP_ISR(ipHigh)
    if (PIR0.0 = 0) then
        PIR0.0 = 0
    endif
end interrupt

// low priority interrupt service routine
public interrupt LOWP_ISR(ipLow)
    if (PIR0.1 = 0) then
        PIR0.1 = 0
    endif
end interrupt

// this kludge defines an RCON register symbol so at least things will compile
// since SF will set/clear RCON.bits(7) automatically at the start of MAIN when 
// using interrupts we locate RCON at the WREG address so it doesn't cause any harm
// you'll have to manage INTCON.IPEN manually
public system RCON as byte absolute $0FE8
asm
RCON EQU 0x0FE8
end asm

IPEN = 1        // this replicates SF startup code
enable(LOWP_ISR)
enable(HIGHP_ISR)
#endif

while (true)
end while

